@@ -73,12 +73,9 @@ sub spawn {
   my $url = <$server>;
   chomp $url;
   die "Couldn't find fake server url" unless $url;
-
+  
   $self->{_fh} = $server;
-
-  my $lhurl = URI::URL->new( $url );
-  $lhurl->host( "localhost" );
-  $self->{_server_url} = $lhurl;
+  $self->{_server_url} = URI::URL->new($url);
 
   $self;
 };
@@ -91,7 +88,7 @@ if you need to compare results from two runs.
 
 =cut
 
-sub port {
+sub port { 
   carp __PACKAGE__ . "::port called without a server" unless $_[0]->{_server_url};
   $_[0]->{_server_url}->port
 };
@@ -106,10 +103,8 @@ C<< $server->get_output >>
 
 =cut
 
-sub url {
-  my $url = $_[0]->{_server_url}->abs;
-
-  return $url->as_string;
+sub url { 
+  $_[0]->{_server_url}->abs
 };
 
 =head2 C<< $server->stop >>
@@ -119,8 +114,8 @@ url.
 
 =cut
 
-sub stop {
-  get( $_[0]->{_server_url} . "quit_server" );
+sub stop { 
+  get( $_[0]->{_server_url} . "quit_server" ); 
   undef $_[0]->{_server_url}
 };
 
@@ -143,7 +138,7 @@ sub get_output {
   join "", <LOG>;
 };
 
-sub DESTROY {
+sub DESTROY { 
   $_[0]->stop if $_[0]->{_server_url};
   for my $file (@{$_[0]->{delete}}) {
     unlink $file or warn "Couldn't remove tempfile $file : $!\n";
